==> bytesize-0.02.tar.gz: bytesize-0.02/tests/config_test.py <==
# Copyright (C) 2015  Red Hat, Inc.
#
# This copyrighted material is made available to anyone wishing to use,
# modify, copy, or redistribute it subject to the terms and conditions of
# the GNU General Public License v.2, or (at your option) any later version.
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY expressed or implied, including the implied warranties of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
# Public License for more details.  You should have received a copy of the
# GNU General Public License along with this program; if not, write to the
# Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.  Any Red Hat trademarks that are incorporated in the
# source code or documentation are not subject to the GNU General Public
# License and may only be used or replicated with the express permission of
# Red Hat, Inc.
#
# Red Hat Author(s): Anne Mulhern <amulhern@redhat.com>

""" Test for configuration classes. """
import unittest

from hypothesis import given
from hypothesis import strategies
from hypothesis import Settings

from bytesize._config import InputConfig
from bytesize._config import SizeConfig
from bytesize._config import StrConfig

from bytesize._constants import RoundingMethods
from bytesize._constants import UNITS

class ConfigTestCase(unittest.TestCase):
    """ Exercise methods of output configuration classes. """
    # pylint: disable=too-few-public-methods

    def testStrConfigObject(self):
        """ Miscellaneous tests for string configuration. """
        self.assertIsNotNone(str(SizeConfig.STR_CONFIG))

class InputTestCase(unittest.TestCase):
    """ Exercise methods of input configuration classes. """
    # pylint: disable=too-few-public-methods

    def testInputConfigObject(self):
        """ Miscellaneous tests for input configuration. """
        self.assertIsNotNone(str(SizeConfig.INPUT_CONFIG))

class SizeTestCase(unittest.TestCase):
    """ Test Size configuration. """
    # pylint: disable=too-few-public-methods

    def setUp(self):
        self.str_config = SizeConfig.STR_CONFIG

    @given(
       strategies.builds(
          StrConfig,
          binary_units=strategies.booleans(),
          max_places=strategies.integers().filter(lambda x: x >= 0),
          min_value=strategies.fractions(),
          show_approx_str=strategies.booleans(),
          strip=strategies.booleans()
       ),
       settings=Settings(max_examples=30)
    )
    def testSettingStrConfig(self, config):
        """ Test that new str config is the correct one. """
        SizeConfig.set_str_config(config)
        self.assertEqual(str(config), str(SizeConfig.STR_CONFIG))

    @given(
       strategies.builds(
          InputConfig,
          method=strategies.sampled_from(RoundingMethods.METHODS()),
          unit=strategies.sampled_from(UNITS())
       ),
       settings=Settings(max_examples=10)
    )
    def testSettingInputConfig(self, config):
        """ That that new input config is the correct one. """
        SizeConfig.set_input_config(config)
        self.assertEqual(str(config), str(SizeConfig.INPUT_CONFIG))

    def tearDown(self):
        SizeConfig.STR_CONFIG = self.str_config

==> bytesize-0.3.tar.gz: bytesize-0.3/tests/config_test.py <==
# Copyright (C) 2015  Red Hat, Inc.
#
# This copyrighted material is made available to anyone wishing to use,
# modify, copy, or redistribute it subject to the terms and conditions of
# the GNU General Public License v.2, or (at your option) any later version.
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY expressed or implied, including the implied warranties of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
# Public License for more details.  You should have received a copy of the
# GNU General Public License along with this program; if not, write to the
# Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.  Any Red Hat trademarks that are incorporated in the
# source code or documentation are not subject to the GNU General Public
# License and may only be used or replicated with the express permission of
# Red Hat, Inc.
#
# Red Hat Author(s): Anne Mulhern <amulhern@redhat.com>

""" Test for configuration classes. """
import unittest

from hypothesis import given
from hypothesis import strategies
from hypothesis import Settings

from bytesize._config import InputConfig
from bytesize._config import SizeConfig
from bytesize._config import StrConfig

from bytesize._constants import RoundingMethods
from bytesize._constants import UNITS

class ConfigTestCase(unittest.TestCase):
    """ Exercise methods of output configuration classes. """
    # pylint: disable=too-few-public-methods

    def testStrConfigObject(self):
        """ Miscellaneous tests for string configuration. """
        self.assertIsNotNone(str(SizeConfig.STR_CONFIG))

class InputTestCase(unittest.TestCase):
    """ Exercise methods of input configuration classes. """
    # pylint: disable=too-few-public-methods

    def testInputConfigObject(self):
        """ Miscellaneous tests for input configuration. """
        self.assertIsNotNone(str(SizeConfig.INPUT_CONFIG))

class SizeTestCase(unittest.TestCase):
    """ Test Size configuration. """
    # pylint: disable=too-few-public-methods

    def setUp(self):
        self.str_config = SizeConfig.STR_CONFIG

    @given(
       strategies.builds(
          StrConfig,
          binary_units=strategies.booleans(),
          max_places=strategies.integers().filter(lambda x: x >= 0),
          min_value=strategies.fractions(),
          show_approx_str=strategies.booleans(),
          strip=strategies.booleans(),
          exact_value=strategies.booleans()
       ),
       settings=Settings(max_examples=30)
    )
    def testSettingStrConfig(self, config):
        """ Test that new str config is the correct one. """
        SizeConfig.set_str_config(config)
        self.assertEqual(str(config), str(SizeConfig.STR_CONFIG))

    @given(
       strategies.builds(
          InputConfig,
          method=strategies.sampled_from(RoundingMethods.METHODS()),
          unit=strategies.sampled_from(UNITS())
       ),
       settings=Settings(max_examples=10)
    )
    def testSettingInputConfig(self, config):
        """ That that new input config is the correct one. """
        SizeConfig.set_input_config(config)
        self.assertEqual(str(config), str(SizeConfig.INPUT_CONFIG))

    def tearDown(self):
        SizeConfig.STR_CONFIG = self.str_config
